window.Gleam.initSearch([{"doc":"json_blueprint","title":"json_blueprint","content":"# json_blueprint\n\njson_blueprint is a Gleam library that simplifies JSON encoding and decoding while automatically generating JSON schemas for your data types.\n\n[![Package Version](https://img.shields.io/hexpm/v/json_blueprint)](https://hex.pm/packages/json_blueprint)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/json_blueprint/)\n\n```sh\ngleam add json_blueprint\n```\n\n## Usage\n\njson_blueprint provides utilities for encoding and decoding JSON data, with special support for union types. The generated JSON schemas can be used to validate incoming JSON data with the decoder. The JSON schema follows the [JSON Schema Draft 7](https://json-schema.org/) specification and can tested and validate on [JSON Schema Lint](https://jsonschemalint.com/#!/version/draft-07/markup/json).\n\n### Encoding Union Types\n\nHere&#39;s an example of encoding a union type to JSON:\n\n```gleam\nimport json/blueprint\nimport gleam/json\nimport gleam/io\nimport gleeunit/should\n\ntype Shape {\n  Circle(Float)\n  Rectangle(Float, Float)\n  Void\n}\n\nfn encode_shape(shape: Shape) -&gt; json.Json {\n  blueprint.union_type_encoder(shape, fn(shape_case) {\n    case shape_case {\n      Circle(radius) -&gt; #(\n        &quot;circle&quot;,\n        json.object([#(&quot;radius&quot;, json.float(radius))]),\n      )\n      Rectangle(width, height) -&gt; #(\n        &quot;rectangle&quot;,\n        json.object([\n          #(&quot;width&quot;, json.float(width)),\n          #(&quot;height&quot;, json.float(height)),\n        ]),\n      )\n      Void -&gt; #(&quot;void&quot;, json.object([]))\n    }\n  })\n}\n\nfn shape_decoder() -&gt; blueprint.Decoder(Shape) {\n  blueprint.union_type_decoder([\n    #(\n      &quot;circle&quot;,\n      blueprint.decode1(Circle, blueprint.field(&quot;radius&quot;, blueprint.float())),\n    ),\n    #(\n      &quot;rectangle&quot;,\n      blueprint.decode2(\n        Rectangle,\n        blueprint.field(&quot;width&quot;, blueprint.float()),\n        blueprint.field(&quot;height&quot;, blueprint.float()),\n      ),\n    ),\n    #(&quot;void&quot;, blueprint.decode0(Void)),\n  ])\n}\n\nfn simple_test() {\n  let decoder = shape_decoder()\n\n  // Test encoding a Circle\n  let circle = Circle(5.0)\n  encode_shape(circle)\n  |&gt; json.to_string\n  |&gt; blueprint.decode(using: decoder)\n  |&gt; should.equal(Ok(circle))\n\n  // Test encoding a Rectangle\n  let rectangle = Rectangle(10.0, 20.0)\n  encode_shape(rectangle)\n  |&gt; json.to_string\n  |&gt; blueprint.decode(using: decoder)\n  |&gt; should.equal(Ok(rectangle))\n\n  // Test encoding a Void\n  encode_shape(Void)\n  |&gt; json.to_string\n  |&gt; blueprint.decode(using: decoder)\n  |&gt; should.equal(Ok(Void))\n\n  // Print JSON schema\n  decoder\n  |&gt; blueprint.generate_json_schema()\n  |&gt; json.to_string\n  |&gt; io.println\n}\n```\n\n```json\n{\n  &quot;$schema&quot;: &quot;http://json-schema.org/draft-07/schema#&quot;,\n  &quot;oneOf&quot;: [\n    {\n      &quot;required&quot;: [&quot;type&quot;, &quot;data&quot;],\n      &quot;additionalProperties&quot;: false,\n      &quot;type&quot;: &quot;object&quot;,\n      &quot;properties&quot;: {\n        &quot;type&quot;: {\n          &quot;enum&quot;: [&quot;circle&quot;]\n        },\n        &quot;data&quot;: {\n          &quot;required&quot;: [&quot;radius&quot;],\n          &quot;additionalProperties&quot;: false,\n          &quot;type&quot;: &quot;object&quot;,\n          &quot;properties&quot;: {\n            &quot;radius&quot;: {\n              &quot;type&quot;: &quot;number&quot;\n            }\n          }\n        }\n      }\n    },\n    {\n      &quot;required&quot;: [&quot;type&quot;, &quot;data&quot;],\n      &quot;additionalProperties&quot;: false,\n      &quot;type&quot;: &quot;object&quot;,\n      &quot;properties&quot;: {\n        &quot;type&quot;: {\n          &quot;enum&quot;: [&quot;rectangle&quot;]\n        },\n        &quot;data&quot;: {\n          &quot;required&quot;: [&quot;width&quot;, &quot;height&quot;],\n          &quot;additionalProperties&quot;: false,\n          &quot;type&quot;: &quot;object&quot;,\n          &quot;properties&quot;: {\n            &quot;width&quot;: {\n              &quot;type&quot;: &quot;number&quot;\n            },\n            &quot;height&quot;: {\n              &quot;type&quot;: &quot;number&quot;\n            }\n          }\n        }\n      }\n    }\n  ]\n}\n```\n\nThis will encode your union types into a standardized JSON format with `type` and `data` fields, making it easy to decode on the receiving end.\n\n## Features\n\n- 🎯 Type-safe JSON encoding and decoding\n- 🔄 Support for union types with standardized encoding\n- 📋 Automatic JSON schema generation\n- ✨ Clean and intuitive API\n\nFurther documentation can be found at &lt;https://hexdocs.pm/json_blueprint&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"json/blueprint/schema","title":"Schema","content":"pub type Schema {\n  Schema(\n    schema: SchemaDefinition,\n    vocabulary: Option(List(String)),\n    id: Option(String),\n    comment: Option(String),\n    defs: Option(List(#(String, SchemaDefinition))),\n  )\n}\n Represents a complete JSON Schema document\nSchema(\n  schema: SchemaDefinition,\n  vocabulary: Option(List(String)),\n  id: Option(String),\n  comment: Option(String),\n  defs: Option(List(#(String, SchemaDefinition))),\n)\n\n\nSynonyms:\njson/blueprint/schema.Schema\njson/blueprint/schema Schema","url":"json/blueprint/schema.html#Schema"},{"doc":"json/blueprint/schema","title":"SchemaDefinition","content":"pub type SchemaDefinition {\n  Type(type_: SchemaType)\n  Enum(values: List(json.Json))\n  Const(value: json.Json)\n  Nullable(schema: SchemaDefinition)\n  Number(\n    minimum: Option(Float),\n    maximum: Option(Float),\n    exclusive_minimum: Option(Float),\n    exclusive_maximum: Option(Float),\n    multiple_of: Option(Float),\n  )\n  String(\n    min_length: Option(Int),\n    max_length: Option(Int),\n    pattern: Option(String),\n    format: Option(StringFormat),\n  )\n  Array(items: Option(SchemaDefinition))\n  DetailedArray(\n    items: Option(SchemaDefinition),\n    prefix_items: Option(List(SchemaDefinition)),\n    min_items: Option(Int),\n    max_items: Option(Int),\n    unique_items: Option(Bool),\n    contains: Option(SchemaDefinition),\n    min_contains: Option(Int),\n    max_contains: Option(Int),\n  )\n  Object(\n    properties: List(#(String, SchemaDefinition)),\n    additional_properties: Option(Bool),\n    required: Option(List(String)),\n  )\n  DetailedObject(\n    properties: Option(List(#(String, SchemaDefinition))),\n    pattern_properties: Option(List(#(String, SchemaDefinition))),\n    additional_properties: Option(SchemaDefinition),\n    required: Option(List(String)),\n    property_names: Option(SchemaDefinition),\n    min_properties: Option(Int),\n    max_properties: Option(Int),\n  )\n  AllOf(schemas: List(SchemaDefinition))\n  AnyOf(schemas: List(SchemaDefinition))\n  OneOf(schemas: List(SchemaDefinition))\n  Not(schema: SchemaDefinition)\n  Ref(ref: String)\n  TrueValue\n  FalseValue\n}\n Core schema definition that can be used recursively\nType(type_: SchemaType)\n\n\nEnum(values: List(json.Json))\n\n\nConst(value: json.Json)\n\n\nNullable(schema: SchemaDefinition)\n\n\nNumber(\n  minimum: Option(Float),\n  maximum: Option(Float),\n  exclusive_minimum: Option(Float),\n  exclusive_maximum: Option(Float),\n  multiple_of: Option(Float),\n)\n\n\nString(\n  min_length: Option(Int),\n  max_length: Option(Int),\n  pattern: Option(String),\n  format: Option(StringFormat),\n)\n\n\nArray(items: Option(SchemaDefinition))\n\n\nDetailedArray(\n  items: Option(SchemaDefinition),\n  prefix_items: Option(List(SchemaDefinition)),\n  min_items: Option(Int),\n  max_items: Option(Int),\n  unique_items: Option(Bool),\n  contains: Option(SchemaDefinition),\n  min_contains: Option(Int),\n  max_contains: Option(Int),\n)\n\n\nObject(\n  properties: List(#(String, SchemaDefinition)),\n  additional_properties: Option(Bool),\n  required: Option(List(String)),\n)\n\n\nDetailedObject(\n  properties: Option(List(#(String, SchemaDefinition))),\n  pattern_properties: Option(List(#(String, SchemaDefinition))),\n  additional_properties: Option(SchemaDefinition),\n  required: Option(List(String)),\n  property_names: Option(SchemaDefinition),\n  min_properties: Option(Int),\n  max_properties: Option(Int),\n)\n\n\nAllOf(schemas: List(SchemaDefinition))\n\n\nAnyOf(schemas: List(SchemaDefinition))\n\n\nOneOf(schemas: List(SchemaDefinition))\n\n\nNot(schema: SchemaDefinition)\n\n\nRef(ref: String)\n\n\nTrueValue\n\n\nFalseValue\n\n\nSynonyms:\njson/blueprint/schema.SchemaDefinition\njson/blueprint/schema SchemaDefinition","url":"json/blueprint/schema.html#SchemaDefinition"},{"doc":"json/blueprint/schema","title":"SchemaType","content":"pub type SchemaType {\n  Null\n  BooleanType\n  ObjectType\n  ArrayType\n  NumberType\n  StringType\n  IntegerType\n  Multiple(List(SchemaType))\n}\n Represents the allowed basic JSON Schema types\nNull\n\n\nBooleanType\n\n\nObjectType\n\n\nArrayType\n\n\nNumberType\n\n\nStringType\n\n\nIntegerType\n\n\nMultiple(List(SchemaType))\n\n\nSynonyms:\njson/blueprint/schema.SchemaType\njson/blueprint/schema SchemaType","url":"json/blueprint/schema.html#SchemaType"},{"doc":"json/blueprint/schema","title":"StringFormat","content":"pub type StringFormat {\n  DateTime\n  Date\n  Time\n  Duration\n  Email\n  IdnEmail\n  Hostname\n  IdnHostname\n  Ipv4\n  Ipv6\n  Uri\n  UriReference\n  Iri\n  IriReference\n  UriTemplate\n  JsonPointer\n  RelativeJsonPointer\n  Regex\n}\n Common string formats defined in the spec\nDateTime\n\n\nDate\n\n\nTime\n\n\nDuration\n\n\nEmail\n\n\nIdnEmail\n\n\nHostname\n\n\nIdnHostname\n\n\nIpv4\n\n\nIpv6\n\n\nUri\n\n\nUriReference\n\n\nIri\n\n\nIriReference\n\n\nUriTemplate\n\n\nJsonPointer\n\n\nRelativeJsonPointer\n\n\nRegex\n\n\nSynonyms:\njson/blueprint/schema.StringFormat\njson/blueprint/schema StringFormat","url":"json/blueprint/schema.html#StringFormat"},{"doc":"json/blueprint/schema","title":"json_schema_version","content":"pub const json_schema_version: String\n\nSynonyms:\njson/blueprint/schema.json_schema_version\njson/blueprint/schema json_schema_version","url":"json/blueprint/schema.html#json_schema_version"},{"doc":"json/blueprint/schema","title":"new_schema","content":"pub fn new_schema(definition: SchemaDefinition) -&gt; Schema\n Helper function to create a new schema with default values\nSynonyms:\njson/blueprint/schema.new_schema\njson/blueprint/schema new_schema","url":"json/blueprint/schema.html#new_schema"},{"doc":"json/blueprint/schema","title":"number_constraint","content":"pub fn number_constraint(\n  minimum minimum: Option(Float),\n  maximum maximum: Option(Float),\n  exclusive_minimum exclusive_minimum: Option(Float),\n  exclusive_maximum exclusive_maximum: Option(Float),\n  multiple_of multiple_of: Option(Float),\n) -&gt; SchemaDefinition\n Helper to create a number constraint\nSynonyms:\njson/blueprint/schema.number_constraint\njson/blueprint/schema number_constraint","url":"json/blueprint/schema.html#number_constraint"},{"doc":"json/blueprint/schema","title":"string_constraint","content":"pub fn string_constraint(\n  min_length min_length: Option(Int),\n  max_length max_length: Option(Int),\n  pattern pattern: Option(String),\n  format format: Option(StringFormat),\n) -&gt; SchemaDefinition\n Helper to create a string constraint\nSynonyms:\njson/blueprint/schema.string_constraint\njson/blueprint/schema string_constraint","url":"json/blueprint/schema.html#string_constraint"},{"doc":"json/blueprint/schema","title":"to_json","content":"pub fn to_json(schema: Schema) -&gt; Json\n Convert a Schema to JSON value\nSynonyms:\njson/blueprint/schema.to_json\njson/blueprint/schema to_json","url":"json/blueprint/schema.html#to_json"},{"doc":"json/blueprint/schema","title":"to_json_string","content":"pub fn to_json_string(schema: Schema) -&gt; String\n Convert a Schema to JSON string\nSynonyms:\njson/blueprint/schema.to_json_string\njson/blueprint/schema to_json_string","url":"json/blueprint/schema.html#to_json_string"},{"doc":"json/blueprint/schema","title":"type_constraint","content":"pub fn type_constraint(type_: SchemaType) -&gt; SchemaDefinition\n Helper to create a basic type constraint\nSynonyms:\njson/blueprint/schema.type_constraint\njson/blueprint/schema type_constraint","url":"json/blueprint/schema.html#type_constraint"},{"doc":"json/blueprint/schema","title":"json/blueprint/schema","content":"","url":"json/blueprint/schema.html"},{"doc":"json/blueprint","title":"Decoder","content":"pub type Decoder(t) =\n  #(dynamic.Decoder(t), SchemaDefinition)\n\n\nSynonyms:\njson/blueprint.Decoder\njson/blueprint Decoder","url":"json/blueprint.html#Decoder"},{"doc":"json/blueprint","title":"FieldDecoder","content":"pub type FieldDecoder(t) =\n  #(dynamic.Decoder(t), #(String, SchemaDefinition))\n\n\nSynonyms:\njson/blueprint.FieldDecoder\njson/blueprint FieldDecoder","url":"json/blueprint.html#FieldDecoder"},{"doc":"json/blueprint","title":"bool","content":"pub fn bool() -&gt; #(\n  fn(Dynamic) -&gt; Result(Bool, List(DecodeError)),\n  SchemaDefinition,\n)\n\nSynonyms:\njson/blueprint.bool\njson/blueprint bool","url":"json/blueprint.html#bool"},{"doc":"json/blueprint","title":"decode","content":"pub fn decode(\n  using decoder: #(\n    fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n    SchemaDefinition,\n  ),\n  from json_string: String,\n) -&gt; Result(a, gleam/json.DecodeError)\n\nSynonyms:\njson/blueprint.decode\njson/blueprint decode","url":"json/blueprint.html#decode"},{"doc":"json/blueprint","title":"decode0","content":"pub fn decode0(\n  constructor: a,\n) -&gt; #(\n  fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  SchemaDefinition,\n)\n\nSynonyms:\njson/blueprint.decode0\njson/blueprint decode0","url":"json/blueprint.html#decode0"},{"doc":"json/blueprint","title":"decode1","content":"pub fn decode1(\n  constructor: fn(a) -&gt; b,\n  t1: #(\n    fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n) -&gt; #(\n  fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n  SchemaDefinition,\n)\n\nSynonyms:\njson/blueprint.decode1\njson/blueprint decode1","url":"json/blueprint.html#decode1"},{"doc":"json/blueprint","title":"decode2","content":"pub fn decode2(\n  constructor: fn(a, b) -&gt; c,\n  t1: #(\n    fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n  t2: #(\n    fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n) -&gt; #(\n  fn(Dynamic) -&gt; Result(c, List(DecodeError)),\n  SchemaDefinition,\n)\n\nSynonyms:\njson/blueprint.decode2\njson/blueprint decode2","url":"json/blueprint.html#decode2"},{"doc":"json/blueprint","title":"decode3","content":"pub fn decode3(\n  constructor: fn(a, b, c) -&gt; d,\n  t1: #(\n    fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n  t2: #(\n    fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n  t3: #(\n    fn(Dynamic) -&gt; Result(c, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n) -&gt; #(\n  fn(Dynamic) -&gt; Result(d, List(DecodeError)),\n  SchemaDefinition,\n)\n\nSynonyms:\njson/blueprint.decode3\njson/blueprint decode3","url":"json/blueprint.html#decode3"},{"doc":"json/blueprint","title":"decode4","content":"pub fn decode4(\n  constructor: fn(a, b, c, d) -&gt; e,\n  t1: #(\n    fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n  t2: #(\n    fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n  t3: #(\n    fn(Dynamic) -&gt; Result(c, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n  t4: #(\n    fn(Dynamic) -&gt; Result(d, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n) -&gt; #(\n  fn(Dynamic) -&gt; Result(e, List(DecodeError)),\n  SchemaDefinition,\n)\n\nSynonyms:\njson/blueprint.decode4\njson/blueprint decode4","url":"json/blueprint.html#decode4"},{"doc":"json/blueprint","title":"decode5","content":"pub fn decode5(\n  constructor: fn(a, b, c, d, e) -&gt; f,\n  t1: #(\n    fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n  t2: #(\n    fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n  t3: #(\n    fn(Dynamic) -&gt; Result(c, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n  t4: #(\n    fn(Dynamic) -&gt; Result(d, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n  t5: #(\n    fn(Dynamic) -&gt; Result(e, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n) -&gt; #(\n  fn(Dynamic) -&gt; Result(f, List(DecodeError)),\n  SchemaDefinition,\n)\n\nSynonyms:\njson/blueprint.decode5\njson/blueprint decode5","url":"json/blueprint.html#decode5"},{"doc":"json/blueprint","title":"decode6","content":"pub fn decode6(\n  constructor: fn(a, b, c, d, e, f) -&gt; g,\n  t1: #(\n    fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n  t2: #(\n    fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n  t3: #(\n    fn(Dynamic) -&gt; Result(c, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n  t4: #(\n    fn(Dynamic) -&gt; Result(d, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n  t5: #(\n    fn(Dynamic) -&gt; Result(e, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n  t6: #(\n    fn(Dynamic) -&gt; Result(f, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n) -&gt; #(\n  fn(Dynamic) -&gt; Result(g, List(DecodeError)),\n  SchemaDefinition,\n)\n\nSynonyms:\njson/blueprint.decode6\njson/blueprint decode6","url":"json/blueprint.html#decode6"},{"doc":"json/blueprint","title":"decode7","content":"pub fn decode7(\n  constructor: fn(a, b, c, d, e, f, g) -&gt; h,\n  t1: #(\n    fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n  t2: #(\n    fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n  t3: #(\n    fn(Dynamic) -&gt; Result(c, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n  t4: #(\n    fn(Dynamic) -&gt; Result(d, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n  t5: #(\n    fn(Dynamic) -&gt; Result(e, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n  t6: #(\n    fn(Dynamic) -&gt; Result(f, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n  t7: #(\n    fn(Dynamic) -&gt; Result(g, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n) -&gt; #(\n  fn(Dynamic) -&gt; Result(h, List(DecodeError)),\n  SchemaDefinition,\n)\n\nSynonyms:\njson/blueprint.decode7\njson/blueprint decode7","url":"json/blueprint.html#decode7"},{"doc":"json/blueprint","title":"decode8","content":"pub fn decode8(\n  constructor: fn(a, b, c, d, e, f, g, h) -&gt; i,\n  t1: #(\n    fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n  t2: #(\n    fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n  t3: #(\n    fn(Dynamic) -&gt; Result(c, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n  t4: #(\n    fn(Dynamic) -&gt; Result(d, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n  t5: #(\n    fn(Dynamic) -&gt; Result(e, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n  t6: #(\n    fn(Dynamic) -&gt; Result(f, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n  t7: #(\n    fn(Dynamic) -&gt; Result(g, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n  t8: #(\n    fn(Dynamic) -&gt; Result(h, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n) -&gt; #(\n  fn(Dynamic) -&gt; Result(i, List(DecodeError)),\n  SchemaDefinition,\n)\n\nSynonyms:\njson/blueprint.decode8\njson/blueprint decode8","url":"json/blueprint.html#decode8"},{"doc":"json/blueprint","title":"decode9","content":"pub fn decode9(\n  constructor: fn(a, b, c, d, e, f, g, h, i) -&gt; j,\n  t1: #(\n    fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n  t2: #(\n    fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n  t3: #(\n    fn(Dynamic) -&gt; Result(c, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n  t4: #(\n    fn(Dynamic) -&gt; Result(d, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n  t5: #(\n    fn(Dynamic) -&gt; Result(e, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n  t6: #(\n    fn(Dynamic) -&gt; Result(f, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n  t7: #(\n    fn(Dynamic) -&gt; Result(g, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n  t8: #(\n    fn(Dynamic) -&gt; Result(h, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n  t9: #(\n    fn(Dynamic) -&gt; Result(i, List(DecodeError)),\n    #(String, SchemaDefinition),\n  ),\n) -&gt; #(\n  fn(Dynamic) -&gt; Result(j, List(DecodeError)),\n  SchemaDefinition,\n)\n\nSynonyms:\njson/blueprint.decode9\njson/blueprint decode9","url":"json/blueprint.html#decode9"},{"doc":"json/blueprint","title":"field","content":"pub fn field(\n  named name: String,\n  of inner_type: #(\n    fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n    SchemaDefinition,\n  ),\n) -&gt; #(\n  fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  #(String, SchemaDefinition),\n)\n\nSynonyms:\njson/blueprint.field\njson/blueprint field","url":"json/blueprint.html#field"},{"doc":"json/blueprint","title":"float","content":"pub fn float() -&gt; #(\n  fn(Dynamic) -&gt; Result(Float, List(DecodeError)),\n  SchemaDefinition,\n)\n\nSynonyms:\njson/blueprint.float\njson/blueprint float","url":"json/blueprint.html#float"},{"doc":"json/blueprint","title":"generate_json_schema","content":"pub fn generate_json_schema(\n  decoder: #(\n    fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n    SchemaDefinition,\n  ),\n) -&gt; Json\n\nSynonyms:\njson/blueprint.generate_json_schema\njson/blueprint generate_json_schema","url":"json/blueprint.html#generate_json_schema"},{"doc":"json/blueprint","title":"get_dynamic_decoder","content":"pub fn get_dynamic_decoder(\n  decoder: #(\n    fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n    SchemaDefinition,\n  ),\n) -&gt; fn(Dynamic) -&gt; Result(a, List(DecodeError))\n\nSynonyms:\njson/blueprint.get_dynamic_decoder\njson/blueprint get_dynamic_decoder","url":"json/blueprint.html#get_dynamic_decoder"},{"doc":"json/blueprint","title":"int","content":"pub fn int() -&gt; #(\n  fn(Dynamic) -&gt; Result(Int, List(DecodeError)),\n  SchemaDefinition,\n)\n\nSynonyms:\njson/blueprint.int\njson/blueprint int","url":"json/blueprint.html#int"},{"doc":"json/blueprint","title":"list","content":"pub fn list(\n  of decoder_type: #(\n    fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n    SchemaDefinition,\n  ),\n) -&gt; #(\n  fn(Dynamic) -&gt; Result(List(a), List(DecodeError)),\n  SchemaDefinition,\n)\n\nSynonyms:\njson/blueprint.list\njson/blueprint list","url":"json/blueprint.html#list"},{"doc":"json/blueprint","title":"map","content":"pub fn map(\n  decoder decoder: #(\n    fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n    SchemaDefinition,\n  ),\n  over foo: fn(a) -&gt; b,\n) -&gt; #(\n  fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n  SchemaDefinition,\n)\n\nSynonyms:\njson/blueprint.map\njson/blueprint map","url":"json/blueprint.html#map"},{"doc":"json/blueprint","title":"optional","content":"pub fn optional(\n  of decode: #(\n    fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n    SchemaDefinition,\n  ),\n) -&gt; #(\n  fn(Dynamic) -&gt; Result(Option(a), List(DecodeError)),\n  SchemaDefinition,\n)\n\nSynonyms:\njson/blueprint.optional\njson/blueprint optional","url":"json/blueprint.html#optional"},{"doc":"json/blueprint","title":"optional_field","content":"pub fn optional_field(\n  named name: String,\n  of inner_type: #(\n    fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n    SchemaDefinition,\n  ),\n) -&gt; #(\n  fn(Dynamic) -&gt; Result(Option(a), List(DecodeError)),\n  #(String, SchemaDefinition),\n)\n\nSynonyms:\njson/blueprint.optional_field\njson/blueprint optional_field","url":"json/blueprint.html#optional_field"},{"doc":"json/blueprint","title":"string","content":"pub fn string() -&gt; #(\n  fn(Dynamic) -&gt; Result(String, List(DecodeError)),\n  SchemaDefinition,\n)\n\nSynonyms:\njson/blueprint.string\njson/blueprint string","url":"json/blueprint.html#string"},{"doc":"json/blueprint","title":"tuple2","content":"pub fn tuple2(\n  first decode1: #(\n    fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n    SchemaDefinition,\n  ),\n  second decode2: #(\n    fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n    SchemaDefinition,\n  ),\n) -&gt; #(\n  fn(Dynamic) -&gt; Result(#(a, b), List(DecodeError)),\n  SchemaDefinition,\n)\n\nSynonyms:\njson/blueprint.tuple2\njson/blueprint tuple2","url":"json/blueprint.html#tuple2"},{"doc":"json/blueprint","title":"tuple3","content":"pub fn tuple3(\n  first decode1: #(\n    fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n    SchemaDefinition,\n  ),\n  second decode2: #(\n    fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n    SchemaDefinition,\n  ),\n  third decode3: #(\n    fn(Dynamic) -&gt; Result(c, List(DecodeError)),\n    SchemaDefinition,\n  ),\n) -&gt; #(\n  fn(Dynamic) -&gt; Result(#(a, b, c), List(DecodeError)),\n  SchemaDefinition,\n)\n\nSynonyms:\njson/blueprint.tuple3\njson/blueprint tuple3","url":"json/blueprint.html#tuple3"},{"doc":"json/blueprint","title":"tuple4","content":"pub fn tuple4(\n  first decode1: #(\n    fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n    SchemaDefinition,\n  ),\n  second decode2: #(\n    fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n    SchemaDefinition,\n  ),\n  third decode3: #(\n    fn(Dynamic) -&gt; Result(c, List(DecodeError)),\n    SchemaDefinition,\n  ),\n  fourth decode4: #(\n    fn(Dynamic) -&gt; Result(d, List(DecodeError)),\n    SchemaDefinition,\n  ),\n) -&gt; #(\n  fn(Dynamic) -&gt; Result(#(a, b, c, d), List(DecodeError)),\n  SchemaDefinition,\n)\n\nSynonyms:\njson/blueprint.tuple4\njson/blueprint tuple4","url":"json/blueprint.html#tuple4"},{"doc":"json/blueprint","title":"tuple5","content":"pub fn tuple5(\n  first decode1: #(\n    fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n    SchemaDefinition,\n  ),\n  second decode2: #(\n    fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n    SchemaDefinition,\n  ),\n  third decode3: #(\n    fn(Dynamic) -&gt; Result(c, List(DecodeError)),\n    SchemaDefinition,\n  ),\n  fourth decode4: #(\n    fn(Dynamic) -&gt; Result(d, List(DecodeError)),\n    SchemaDefinition,\n  ),\n  fifth decode5: #(\n    fn(Dynamic) -&gt; Result(e, List(DecodeError)),\n    SchemaDefinition,\n  ),\n) -&gt; #(\n  fn(Dynamic) -&gt; Result(#(a, b, c, d, e), List(DecodeError)),\n  SchemaDefinition,\n)\n\nSynonyms:\njson/blueprint.tuple5\njson/blueprint tuple5","url":"json/blueprint.html#tuple5"},{"doc":"json/blueprint","title":"tuple6","content":"pub fn tuple6(\n  first decode1: #(\n    fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n    SchemaDefinition,\n  ),\n  second decode2: #(\n    fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n    SchemaDefinition,\n  ),\n  third decode3: #(\n    fn(Dynamic) -&gt; Result(c, List(DecodeError)),\n    SchemaDefinition,\n  ),\n  fourth decode4: #(\n    fn(Dynamic) -&gt; Result(d, List(DecodeError)),\n    SchemaDefinition,\n  ),\n  fifth decode5: #(\n    fn(Dynamic) -&gt; Result(e, List(DecodeError)),\n    SchemaDefinition,\n  ),\n  sixth decode6: #(\n    fn(Dynamic) -&gt; Result(f, List(DecodeError)),\n    SchemaDefinition,\n  ),\n) -&gt; #(\n  fn(Dynamic) -&gt; Result(#(a, b, c, d, e, f), List(DecodeError)),\n  SchemaDefinition,\n)\n\nSynonyms:\njson/blueprint.tuple6\njson/blueprint tuple6","url":"json/blueprint.html#tuple6"},{"doc":"json/blueprint","title":"union_type_decoder","content":"pub fn union_type_decoder(\n  constructor_decoders decoders: List(\n    #(\n      String,\n      #(\n        fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n        SchemaDefinition,\n      ),\n    ),\n  ),\n) -&gt; #(\n  fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  SchemaDefinition,\n)\n Function to defined a decoder for a union types.\n The function takes a list of decoders for each possible type of the union.\n\n&gt; [!IMPORTANT]  \n&gt; Make sure to add tests for every possible type of the union because it is not possible to check for exhaustiveness in the case.\n\n ## Example\n \n type Shape {\n   Circle(Float)\n   Rectangle(Float, Float)\n }\n\n let shape_decoder = union_type_decoder([\n   #(&quot;circle&quot;, decode1(Circle, field(&quot;radius&quot;, float()))),\n   #(&quot;rectangle&quot;, decode2(Rectangle, \n     field(&quot;width&quot;, float()),\n     field(&quot;height&quot;, float())\n   ))\n ])\n \n\nSynonyms:\njson/blueprint.union_type_decoder\njson/blueprint union_type_decoder","url":"json/blueprint.html#union_type_decoder"},{"doc":"json/blueprint","title":"union_type_encoder","content":"pub fn union_type_encoder(\n  value of: a,\n  encoder_fn encoder_fn: fn(a) -&gt; #(String, Json),\n) -&gt; Json\n Function to encode a union type into a JSON object.\n The function takes a value and an encoder function that returns a tuple of the type name and the JSON value.\n\n&gt; [!IMPORTANT]  \n&gt; Make sure to update the decoder function accordingly.\n\n ## Example\n \n type Shape {\n   Circle(Float)\n   Rectangle(Float, Float)\n }\n\n let shape_encoder = union_type_encoder(fn(shape) {\n   case shape {\n     Circle(radius) -&gt; #(&quot;circle&quot;, json.object([#(&quot;radius&quot;, json.float(radius))]))\n     Rectangle(width, height) -&gt; #(\n       &quot;rectangle&quot;,\n       json.object([\n         #(&quot;width&quot;, json.float(width)),\n         #(&quot;height&quot;, json.float(height))\n       ])\n     )\n   }\n })\n \n\n\nSynonyms:\njson/blueprint.union_type_encoder\njson/blueprint union_type_encoder","url":"json/blueprint.html#union_type_encoder"},{"doc":"json/blueprint","title":"json/blueprint","content":"","url":"json/blueprint.html"}]);